library(tidyverse)
library(haven)
library(survey)
library(ggeffects)
library(nnet)
library(extrafont)
loadfonts(device = "win", quiet = T)


### Load and recode data

ob <- read_dta("georgia_crrc_omnibus_w3.dta")
### Code variables
ob <- ob %>%  
  mutate_at(vars(starts_with("d3_")), function(x) replace(x, x<0, 0))

ob <- ob %>%
  mutate(wealth = rowSums(select(ob, starts_with("d3_"))),
    fes1_dkra = case_when(
      fes1 < 0 ~ 98,
      T ~ as.numeric(fes1)),
    fes1_support_binary = case_when(
      fes1 == 1 | fes1 == 2 ~ 1,
      T ~ 0
    ),
    fes1_oppose_binary = case_when(
      fes1 == 3 | fes1 == 4 ~ 1,
      T ~ 0
    ),
    fes2_res = case_when(
      fes2 < 0 ~ NA_real_,
      T ~ as.numeric(fes2)
    ),
    fes2_dkra = case_when(
      fes2 < -2 ~ NA_real_,
      T ~ as.numeric(fes2)
    ),
    fes_31_dkra = case_when(
      fes3_1 < 0 | fes3_1 > 10 ~ NA_real_,
      fes3_1 %in% c(1, 2, 3, 4, 5) ~ 1,
      fes3_1 %in% c(6, 7, 8, 9, 10) ~ 2,
    ),
    fes_32_dkra = case_when(
      fes3_2 < 0 | fes3_2 > 10 ~ NA_real_,
      fes3_2 %in% c(1, 2, 3, 4, 5) ~ 1,
      fes3_2 %in% c(6, 7, 8, 9, 10) ~ 2,
    ),
    fes_32_wants_work = case_when(
      fes3_2 < 0 | fes3_2 > 10 ~ 0,
      T ~ 1
      ),
    fes4_res = case_when(
      fes4 < 0 ~ NA_real_,
      T ~ as.numeric(fes4)
    ),
    employment = case_when(
      d1 %in% c(5, 6) ~ 1,
      T ~ 0
    ),
    education = case_when(
      d2 < 3 ~ 1,
      d2 == 3 ~ 2,
      T ~ 3
    ),
    agegroup = case_when(
      age < 35 ~ 1,
      age > 34 & age < 55 ~ 2,
      T ~ 3
    ),
    ethnicity = case_when(
      d6 == 3 ~ 1,
      T ~ 2
    )) %>%
  ### Make factors
  mutate(
    fes1_dkra = factor(fes1_dkra, levels=c(1, 2, 3, 4, 98),
                       labels=c("Fully support", "Partially support", "Partially oppose", "Fully oppose", "DK/RA")),
    fes_31_dkra = factor(fes_31_dkra, levels=c(1, 2), labels=c("White-collar", "Blue-collar")),
    fes_32_dkra = factor(fes_32_dkra, levels=c(1, 2), labels=c("White-collar", "Blue-collar")),
    education = factor(education, levels=c(1, 2, 3), labels=c("Secondary or lower", "Vocational", "Higher")),
    agegroup = factor(agegroup, levels=c(1, 2, 3), labels=c("18-34", "35-54", "55+")),
    ethnicity = factor(ethnicity, levels=c(1, 2), labels=c("Georgian", "Other")),
    sex=droplevels(as_factor(sex)),
    settype=as_factor(stratum)
  )



ob_svy <- svydesign(ids = ~1, strata=NULL, weights = ~weight, data = ob)

svymean(~fes1_dkra, na.rm=T, design=ob_svy)
svyby(~fes1_dkra, by=~education, svymean, na.rm=T, design=ob_svy)%>%
  data.frame()%>%
  gather(coef, tvalues, -education)%>%
  slice(1:15)%>%
  mutate(categories=gsub("fes1_dkra","", coef),
         categories=gsub("\\."," ", categories),
         categories= factor(categories, levels=c("Fully support", "Partially support",
                                                 "Partially oppose", "Fully oppose", "DK RA")))%>%
  ggplot(aes(forcats::fct_rev(categories), tvalues, fill=categories))+
  geom_col()+
  # scale_fill_manual(values=c("#00429d", "#93003a", "#999999"))+
  geom_text(aes(categories, tvalues, label=round(tvalues*100, 0)),
            position=position_dodge(width = 1))+
  scale_y_continuous(labels = scales::percent_format(), limits=c(0,1))+
  facet_wrap(~education)+
  coord_flip()+
  # facet_wrap(~sex)+
  labs(title="Support for minimum wage",
       subtitle = "By party identification",
       caption = "Results are weighted",
       y="Proportion")+
  theme_bw()+
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        axis.title.x = element_blank(),
        strip.placement = "outside",
        strip.background = element_rect(fill = "white"),
        axis.title = element_blank())


mw_support <- svyglm(fes1_support_binary~sex+age+settype+ethnicity+education+employment+wealth, design=ob_svy)

summary(mw_support)

ggpredict(mw_support, terms = "ethnicity", data = ob_svy$variables)

ggpredict(mw_support, terms = "education", data = ob_svy$variables)

ggpredict(mw_support, terms = "age[20, 40, 60]", data = ob_svy$variables)

mw_oppose <- svyglm(fes1_oppose_binary~sex+age+settype+ethnicity+education+employment+wealth, design=ob_svy)

summary(mw_oppose)

ggpredict(mw_oppose, terms = "ethnicity", data = ob_svy$variables)

ggpredict(mw_oppose, terms = "employment", data = ob_svy$variables)

ggpredict(mw_oppose, terms = "wealth[0, 4, 6, 8, 10]", data = ob_svy$variables)


svychisq(~fes1_dkra+sex, design=ob_svy)
svychisq(~fes1_dkra+education, design=ob_svy)
svychisq(~fes1_dkra+employment, design=ob_svy)
svychisq(~fes1_dkra+stratum, design=ob_svy)
svychisq(~fes1_support_binary+party_id, design=ob_svy)

svymean(~fes2_res, na.rm=T, design=ob_svy)

mw_value <- svyglm(fes2_res~sex+age+settype+ethnicity+education+employment+wealth, design=ob_svy)
summary(mw_value)

svymean(~fes2_res, na.rm=T, design=ob_svy)[1]
svyquantile(~fes2_res, na.rm=T, design=ob_svy, quantiles = 0.5, ci=T)$quantiles
svyby(~fes2_res, ~sex, svymean, na.rm=T, design=ob_svy)
svyby(~fes2_res, ~sex, design = ob_svy, svyquantile, quantiles = 0.5, ci=T, na.rm=T)
svyby(~fes2_res, ~settype, svymean, na.rm=T, design=ob_svy)
svyby(~fes2_res, ~settype, design = ob_svy, svyquantile, quantiles = 0.5, ci=T, na.rm=T)
svyby(~fes2_res, ~ethnicity, svymean, na.rm=T, design=ob_svy)
svyby(~fes2_res, ~ethnicity, design = ob_svy, svyquantile, quantiles = 0.5, ci=T, na.rm=T)

fes2_mm <- read.csv("fes2_mm.csv", sep="\t", stringsAsFactors = F)%>%
  mutate(group=factor(group, levels=c("Nationwide", "Male", "Female", "Capital", "Urban", "Rural", "Georgian", "Ethnic minority")),
         statistic=factor(statistic, levels=c("Mean", "Median")))

fes2_mm %>%
  ggplot(aes(forcats::fct_rev(group), value))+
  geom_point()+
  geom_segment( aes(xend=group, yend=500)) +
  geom_text(aes(group, value, label=round(value, 1)), vjust = -0.5, size = 3)+
  ylim(500, 1000)+
  coord_flip()+
  facet_wrap(~statistic)+
  labs(caption = "Results are weighted",
       x="Population groups",
       y="Perceived minimum wage, in ₾")+
  theme_bw()+
  theme(legend.position = "bottom",
        legend.title = element_blank())



mw_value_p <- svyglm(fes4_res~sex+age+settype+ethnicity+education+fes_31_dkra+wealth, design=ob_svy)
summary(mw_value)

svyby(~fes4_res, ~employment, svymean, na.rm=T, design=ob_svy)
svyby(~fes4_res, ~employment, design = ob_svy, svyquantile, quantiles = 0.5, ci=T, na.rm=T)

svyby(~fes4_res, ~fes_32_wants_work, svymean, na.rm=T, design=ob_svy)
svyby(~fes4_res, ~fes_32_wants_work, design = ob_svy, svyquantile, quantiles = 0.5, ci=T, na.rm=T)

svymean(~fes_31_dkra, na.rm=T, design=ob_svy)
svymean(~fes_32_dkra, na.rm=T, design=ob_svy)

svyby(~fes4_res, ~fes_31_dkra, svymean, na.rm=T, design=ob_svy)
svyby(~fes4_res, ~fes_31_dkra, design = ob_svy, svyquantile, quantiles = 0.5, ci=T, na.rm=T)

svyby(~fes4_res, ~fes_32_dkra, svymean, na.rm=T, design=ob_svy)
svyby(~fes4_res, ~fes_32_dkra, design = ob_svy, svyquantile, quantiles = 0.5, ci=T, na.rm=T)





mw_value_p <- svyglm(fes4_res~sex+age+settype+ethnicity+education+fes_32_dkra+wealth, design=ob_svy)
summary(mw_value)

svyby(~fes4_res, ~fes_32_dkra, svymean, na.rm=T, design=ob_svy)
svyby(~fes4_res, ~fes_32_dkra, design = ob_svy, svyquantile, quantiles = 0.5, ci=T, na.rm=T)


### Visualization

svymean(~fes1_dkra, na.rm=T, design=ob_svy)%>%
  data.frame()%>%
  mutate(categories=gsub("fes1_dkra","", row.names(.)),
         categories= factor(categories, levels=c("Fully support", "Partially support",
                                                 "Partially oppose", "Fully oppose", "DK/RA")))%>%
  ggplot(aes(forcats::fct_rev(categories), mean, fill=categories))+
  geom_col()+
  geom_linerange(aes(ymin=mean-1.96*SE, ymax=mean+1.96*SE), size=1)+
  geom_text(aes(categories, mean, label=round(mean*100, 0)), hjust = -5, size = 3)+
  scale_fill_manual(values=c("#018571", "#80cdc1", "#dfc27d", "#a6611a",  "#999999"))+
  scale_y_continuous(labels = scales::percent_format(), limits=c(0,1))+
  coord_flip()+
  labs(caption = "Results are weighted. Line ranges represent 95% confidence intervals",
       y="Proportion")+
  theme_bw()+
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        axis.title.x = element_blank(),
        axis.title.y = element_blank())

fes1_pp <- read.csv("pprobs.csv", sep="\t", stringsAsFactors = F)%>%
  mutate(variable=factor(variable, levels=c("Ethnicity", "Education", "Age", "Employment status", "Wealth index")),
         category=factor(category, levels=c("Georgian", "Ethnic minority", "Secondary or lower", "Vocational", "Higher", "20", "40", "60", "Employed", "Unemployed", "0", "4", "6", "8", "10")),
         model=factor(model, levels=c("Support", "Oppose")))
  
fes1_pp %>%
  ggplot(aes(forcats::fct_rev(category), probability, color=variable))+
  geom_point()+
  geom_segment(aes(xend=category, yend=0)) +
  geom_text(aes(category, probability, label=round(probability*100, 0)), vjust = -0.5, size = 3)+
  coord_flip()+
  scale_y_continuous(labels = scales::percent_format(), limits=c(0,1))+
  scale_color_manual(values=c("#e41a1c", "#377eb8", "#4daf4a", "#984ea3", "#ff7f00"))+
  facet_grid(model~., scales="free")+
  labs(caption = "Results are weighted",
       x="Population groups",
       y="Probability")+
  theme_bw()+
  theme(strip.placement = "bottom",
        strip.switch.pad.grid = unit("0.25", "cm"),
        strip.text.y = element_text(angle = 0),
        legend.position = "bottom",
        legend.title = element_blank())


fes3_mm <- read.csv("fes3_mm.csv", sep="\t", stringsAsFactors = F)%>%
  mutate(group=factor(group, levels=c("Employed respondents", "White-collar workers", "Blue-collar workers", "Unemployed respondents",
                                      "Willing to take a white-collar job", "Willing to take a blue-collar job")),
         statistic=factor(statistic, levels=c("Mean", "Median")))


fes3_mm %>%
  ggplot(aes(forcats::fct_rev(group), value))+
  geom_point()+
  geom_segment( aes(xend=group, yend=500))+
  geom_text(aes(group, value, label=value), vjust = -0.5, size = 3, family="Georgia")+
  ylim(500, 1500)+
  coord_flip()+
  facet_wrap(~statistic)+
  labs(caption = "The question was asked only to those respondents who support minimum wage in Georgia (75%)",
       x="Population groups",
       y="Reasonable minimum wage, in GEL")+
  theme_bw()+
  theme(plot.caption = element_text(family="Georgia"),
        axis.text.y = element_text(family="Georgia"),
        axis.text.x = element_text(family="Georgia"),
        text = element_text(family="Georgia"),
        legend.position = "bottom",
        legend.title = element_blank())


